library(sealevel)
library(plyr)
library(rjson)
library(ncdf4)
library(reshape2)
library(circular)


## Not used yet....
## IB correction
url <- basename(get.hadslp2.url())
con <- nc_open(url)
lat <- ncvar_get(con, "lat")
lon <- ncvar_get(con, "lon")
slp <- ncvar_get(con, "slp")
t <- ncvar_get(con, "time")
dimnames(slp) <- list(lon, lat, t)
slp.df <- melt(slp)
names(slp.df) <- c("lon", "lat", "t", "slp")


## GIA
url <- basename(get.peltier2004.url('sea'))
con <- nc_open(url)
Lon <- ncvar_get(con, "Lon")
Lat <- ncvar_get(con, "Lat")
Dsea <- ncvar_get(con, "Dsea_250")
dimnames(Dsea) <- list(Lon, Lat)
peltier.df <- melt(Dsea)
names(peltier.df) <- c("lon","lat","dsea")


# Dutch wind
url <- "etmgeg_235.nc"
filename <- basename(url)
con <- nc_open(filename)
windspeed <- ncvar_get(con, varid="wind_speed_mean")
airpressure <- ncvar_get(con, varid="surface_air_pressure_mean")
windfrom <- ncvar_get(con, varid="wind_from_direction_mean")
t <- ncvar_get(con, varid="time")

## windto <- windfrom + 180
## e1 <- which(windto>360)
## windto[e1]  <- windto[e1] -360
windto <- (windfrom + 180) %% 360

u <- cos(pi/180*(windto))*windspeed^2
v <- sin(pi/180*(windto))*windspeed^2

t.sec <- t*24*60*60
t.posixct <- as.POSIXct(t.sec, tz="UTC", origin="1970-01-01 00:00")
t.year <- as.numeric(format(t.posixct,"%Y"))


wind.df <- data.frame(day=t,
                      year.month=t.year,
                      windspeed=windspeed,
                      direction= windto,
                      u=u,
                      v=v,
                      p=airpressure)
#wind.df.mean <- ddply(wind.df, c("year.month"), colMeans)[,c("year.month", "u", "v", "p")]
wind.df.mean <- aggregate(cbind(windspeed,u,v,p)~year.month,data=wind.df,FUN=mean)



## Will be downloaded in the makefile
url <- get.psmsl.url("annual")
## The name of the file
filename <- basename(url)
stations <- read.psmsl(filename)


stations.sel <- c("VLISSINGEN", "HOEK VAN HOLLAND", "DEN HELDER", "DELFZIJL",  "HARLINGEN", "IJMUIDEN")
stations.dutch <- Filter(function(station){station$name %in% stations.sel}, stations)
stations.dutch.df <- ldply(stations.dutch, function(station){station$data})


## Make a mean station
station.mean <- list()

station.mean$ID <- max(as.numeric(names(stations)))+1
station.mean$latitude <- mean(laply(stations.dutch, function(station){station$latitude}))
station.mean$longitude <- mean(laply(stations.dutch, function(station){station$longitude}))
station.mean$name <- "DUTCH MEAN"
station.mean$coastline.code <- 150
station.mean$station.code <- 10000
station.mean$quality.flag <- "N"
station.mean$data <- aggregate(waterlevel ~ year.month, data=stations.dutch.df, FUN=mean)
station.mean$data$days.missing <- "N"
station.mean$data$flag <- 0
stations[[as.character(station.mean$ID)]] <- station.mean

## Simplify the element
stations.l <- llply(stations, function(station) {
    df <- na.omit(station$data[,c("year.month", "waterlevel")])


    if (station$coastline.code == 150) {
        df <- join( df,wind.df.mean)
    }
    df$year.month <- df$year.month - 1970
    fit <- lm(waterlevel ~ year.month, df)
    wl1970 <- predict(fit, newdata=data.frame(year.month=0, waterlevel=0))
    wl1900 <- predict(fit, newdata=data.frame(year.month=-70, waterlevel=0))

    ## Recalculate the fit, with the changed waterlevel
    fit <- lm(waterlevel ~ year.month, df)


    colnames(df)[1:2] <- c("y", "h")

    l <- as.list(df)
    l["wl1900"] <- wl1900
    l["wl1970"] <- wl1970
    l["lat"] <- station$latitude
    l["lon"] <- station$longitude
    l["id"] <- station$ID
    l["name"] <- station$name
    l[["coef"]] <- as.list(coef(fit))
    ## TODO: replace by interpolation...
    l["peltier"] <- peltier.df[(peltier.df$lon == (round(station$longitude)%%360) & peltier.df$lat == round(station$latitude -0.5)+ 0.5), "dsea" ]

    return(l)
}, .parallel=TRUE)


## drop the element names
names(stations.l) <- NULL
## dump to json
json = toJSON(stations.l)
## store in file
cat(json, file="psmsl.json")

# no need to save data here...
stations.l <- llply(stations.l, function(station) {
    station$y <- station$y + 1970
    return(station)
})

## For the Rdata we want to index by names
names(stations.l) <- laply(stations.l, function(station){station$name})
## Save to file, for faster access.
save(stations.l, file="stations.l.rdata")


